Studies
##########

Some of the work-in-progress studies.

.. toctree::
   :maxdepth: 1

   HRV Review <https://www.mdpi.com/1424-8220/21/12/3998>
   HRV Indices <https://psyarxiv.com/mwa6x/>
   HRV Tutorial <https://www.ncbi.nlm.nih.gov/pmc/articles/PMC9307944/>
   Complexity Review <https://onlinelibrary.wiley.com/doi/10.1111/ejn.15800>
   Complexity Indices <https://www.mdpi.com/1099-4300/24/8/1036>
   EEG Complexity: Parameters Selection <complexity_eeg>
   EEG Analysis with GAMs <erp_gam>
   ECG Benchmark <ecg_benchmark>
   EOG blink template <eog_blinktemplate>

